using System;
using System.Windows.Forms;

namespace DBControls
{
	/// <summary>
	/// Subclasses the RichTextBox to allow control over flicker
	/// </summary> 
	public class FlickerFreeRichEditTextBox : RichTextBox
	{
		const short WM_PAINT = 0x00f;
		public static bool _Paint = true;

		public FlickerFreeRichEditTextBox()
		{
		}
		
		protected override void WndProc(ref System.Windows.Forms.Message m)
		{
			/// Code courtesy of Mark Mihevc
			/// sometimes we want to eat the paint message so we don't have to see all the
			/// flicker from when we select the text to change the color.
			
			if (m.Msg == WM_PAINT)
			{
				if (_Paint)
				{
					/// if we decided to paint this control, just call the RichTextBox WndProc
					base.WndProc(ref m);	
				}
				else
				{
					/// not painting, must set this to IntPtr.Zero if not painting otherwise serious problems.
					m.Result = IntPtr.Zero; 
				}
			}
			else
			{
				/// message other than WM_PAINT, hand it over to the base class
				base.WndProc (ref m);   
			}

		}
	}
}
